==> rospell-2007.02.rc1.tar.gz: rospell-2007.02.rc1/src/rospell/beautydialog.cpp <==
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


#include "beautydialog.h"
#ifdef USING_QT4
#include <Q3VBoxLayout>
#include <q3hbox.h>
#include <q3accel.h>
#include <QLabel>
#endif
#ifdef USING_QT3
#include <qlayout.h>
#include <qhbox.h>
#include <qaccel.h>
#include <qlabel.h>
#endif

#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qhbuttongroup.h>
#include <qvbox.h>


//*****************************************************************************/
// ctags dialog
//*****************************************************************************/
BeautyDialog::BeautyDialog(): QDialog(0, "ctags selection", true) {
	Q3VBoxLayout *vly = new Q3VBoxLayout(this, 10, 10);
	vly->setAutoAdd(true);
	Q3VBox *vbox = new Q3VBox(this);
	vbox->setSpacing(10);

	// code line braces
	group1_ = new QHButtonGroup("code line braces", vbox);
	group1_->setExclusive(true);
	b1_ = new QCheckBox("on line", group1_);
	group1_->insert(b1_);
	QCheckBox *b2 = new QCheckBox("on next line", group1_);
	group1_->insert(b2);
	if (Global::instance()->beauty_bcl) {
#ifdef USING_QT4
		b1_->setOn(true);
#else
		b1_->setChecked(true);
#endif
	}
	else {
#ifdef USING_QT4
		b2->setOn(true);
#else
		b2->setChecked(true);
#endif
	}

	// function braces
	group2_ = new QHButtonGroup("function braces", vbox);
	group2_->setExclusive(true);
	b3_ = new QCheckBox("on line", group2_);
	group2_->insert(b3_);
	QCheckBox *b4 = new QCheckBox("on next line", group2_);
	group2_->insert(b4);
	if (Global::instance()->beauty_tbcl) {
#ifdef USING_QT4
		b3_->setOn(true);
#else
		b3_->setChecked(true);
#endif
	}
	else {
#ifdef USING_QT4
		b4->setOn(true);
#else
		b4->setChecked(true);
#endif
	}

	// indent
	group3_ = new QHButtonGroup("indent using", vbox);
	group3_->setExclusive(true);
	b5_ = new QCheckBox("tabs", group3_);
	group3_->insert(b5_);
	QCheckBox *b6 = new QCheckBox("spaces", group3_);
	group3_->insert(b6);
	if (Global::instance()->beauty_tab) {
#ifdef USING_QT4
		b5_->setOn(true);
#else
		b5_->setChecked(true);
#endif
	}
	else {
#ifdef USING_QT4
		b6->setOn(true);
#else
		b6->setChecked(true);
#endif
	}

	// some empty space
	Q3HBox *hbox20 = new Q3HBox(this);
	hbox20->setMargin(10);

	// accept/reject
	Q3HBox *hbox2 = new Q3HBox(this);
	hbox2->setSpacing(10);
	// some empty space
	(new QWidget(hbox2))->setMinimumWidth(80);
	(new QWidget(hbox2))->setMinimumWidth(80);
	button_reload_ = new QPushButton("Ok", hbox2);
	button_cancel_ = new QPushButton("Cancel", hbox2);
	connect(button_reload_, SIGNAL(clicked()), SLOT(accept()));
	connect(button_cancel_, SIGNAL(clicked()), SLOT(reject()));



//	setSizeGripEnabled(true);
}

/* current command line options supported buy robccp
            "-bcl          : Open braces on code line",
            "-bnl          : Open braces on new line",
            "-cc  <num>    : Column to align comments with code",
            "-f   <num>    : Function line spacing",
            "-fi <string>  : Input file name",
            "-fnc <string> : Load custom configuration file",
            "-fo <string>  : Output file name",
            "-h    or   -? : This help message",
            "-i   <num>    : Indent space length",
            "-lg           : Leave graphic chars",
            "-nc  <num>    : Column to align comments with no code",
            "-qb  <num>    : Define internal queue buffer size",
            "-s            : Use spaces in indenting",
            "-t            : Use tabs in indenting",
            "-tbcl         : Top-level open braces on code line",
            "-tbnl         : Top-level open braces on new line",
            "",
            "Options beginning with -n or -y disable/enable functions:",
            "  a           : Remove non-ASCII chars",
            "  b           : Backup input file with .bac extension",
            "  bbi         : Indent both braces of a block",
            "  bi          : Indent trailing brace of block",
            "  lcnc        : Leave comments with NoCode",
            "  o           : Program output",
            "  q           : Change non-ASCII chars in quotes to octal",
*/

QString BeautyDialog::getCmd(QString file) {
	QString retval = "robcpp -ylcnc ";

	if (b1_->isChecked()) {
		Global::instance()->beauty_bcl = true;
		retval += "-bcl ";
	}
	else {
		Global::instance()->beauty_bcl = false;
		retval += "-bnl ";
	}

	if (b3_->isChecked()) {
		Global::instance()->beauty_tbcl = true;
		retval += "-tbcl ";
	}
	else {
		Global::instance()->beauty_tbcl = false;
		retval += "-tbnl ";
	}

	if (b5_->isChecked()) {
		Global::instance()->beauty_tab = true;
		retval += "-t ";
	}
	else {
		Global::instance()->beauty_tab = false;
		retval += "-s ";
	}

	retval += file;

	return retval;
}

==> rospell-2009.00-rc2.tar.gz: rospell-2009.00-rc2/src/rospell/beautydialog.cpp <==
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


#include "beautydialog.h"
#ifdef USING_QT4
#include <Q3VBoxLayout>
#include <q3hbox.h>
#include <q3vbox.h>
#include <q3accel.h>
#include <QLabel>
#include <Q3HButtonGroup>
#endif
#ifdef USING_QT3
#include <qlayout.h>
#include <qhbox.h>
#include <qvbox.h>
#include <qaccel.h>
#include <qlabel.h>
#include <qhbuttongroup.h>
#endif

#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>


//*****************************************************************************/
// ctags dialog
//*****************************************************************************/
BeautyDialog::BeautyDialog(): QDialog(0, "ctags selection", true) {
	Q3VBoxLayout *vly = new Q3VBoxLayout(this, 10, 10);
	vly->setAutoAdd(true);
	Q3VBox *vbox = new Q3VBox(this);
	vbox->setSpacing(10);

	// code line braces
	group1_ = new Q3HButtonGroup(tr("Code line braces: "), vbox);
	group1_->setExclusive(true);
	b1_ = new QCheckBox(tr("on line"), group1_);
	group1_->insert(b1_);
	QCheckBox *b2 = new QCheckBox(tr("on next line"), group1_);
	group1_->insert(b2);
	if (Global::instance()->beauty_bcl) {
#ifdef USING_QT4
		b1_->setOn(true);
#else
		b1_->setChecked(true);
#endif
	}
	else {
#ifdef USING_QT4
		b2->setOn(true);
#else
		b2->setChecked(true);
#endif
	}

	// function braces
	group2_ = new Q3HButtonGroup(tr("Function braces: "), vbox);
	group2_->setExclusive(true);
	b3_ = new QCheckBox(tr("on line"), group2_);
	group2_->insert(b3_);
	QCheckBox *b4 = new QCheckBox(tr("on next line"), group2_);
	group2_->insert(b4);
	if (Global::instance()->beauty_tbcl) {
#ifdef USING_QT4
		b3_->setOn(true);
#else
		b3_->setChecked(true);
#endif
	}
	else {
#ifdef USING_QT4
		b4->setOn(true);
#else
		b4->setChecked(true);
#endif
	}

	// indent
	group3_ = new Q3HButtonGroup(tr("Indent using: "), vbox);
	group3_->setExclusive(true);
	b5_ = new QCheckBox(tr("tabs"), group3_);
	group3_->insert(b5_);
	QCheckBox *b6 = new QCheckBox(tr("spaces"), group3_);
	group3_->insert(b6);
	if (Global::instance()->beauty_tab) {
#ifdef USING_QT4
		b5_->setOn(true);
#else
		b5_->setChecked(true);
#endif
	}
	else {
#ifdef USING_QT4
		b6->setOn(true);
#else
		b6->setChecked(true);
#endif
	}

	// some empty space
	Q3HBox *hbox20 = new Q3HBox(this);
	hbox20->setMargin(10);

	// accept/reject
	Q3HBox *hbox2 = new Q3HBox(this);
	hbox2->setSpacing(10);
	// some empty space
	(new QWidget(hbox2))->setMinimumWidth(80);
	(new QWidget(hbox2))->setMinimumWidth(80);
	button_reload_ = new QPushButton(tr("OK"), hbox2);
	button_cancel_ = new QPushButton(tr("Cancel"), hbox2);
	connect(button_reload_, SIGNAL(clicked()), SLOT(accept()));
	connect(button_cancel_, SIGNAL(clicked()), SLOT(reject()));



//	setSizeGripEnabled(true);
}

/* current command line options supported buy robccp
            "-bcl          : Open braces on code line",
            "-bnl          : Open braces on new line",
            "-cc  <num>    : Column to align comments with code",
            "-f   <num>    : Function line spacing",
            "-fi <string>  : Input file name",
            "-fnc <string> : Load custom configuration file",
            "-fo <string>  : Output file name",
            "-h    or   -? : This help message",
            "-i   <num>    : Indent space length",
            "-lg           : Leave graphic chars",
            "-nc  <num>    : Column to align comments with no code",
            "-qb  <num>    : Define internal queue buffer size",
            "-s            : Use spaces in indenting",
            "-t            : Use tabs in indenting",
            "-tbcl         : Top-level open braces on code line",
            "-tbnl         : Top-level open braces on new line",
            "",
            "Options beginning with -n or -y disable/enable functions:",
            "  a           : Remove non-ASCII chars",
            "  b           : Backup input file with .bac extension",
            "  bbi         : Indent both braces of a block",
            "  bi          : Indent trailing brace of block",
            "  lcnc        : Leave comments with NoCode",
            "  o           : Program output",
            "  q           : Change non-ASCII chars in quotes to octal",
*/

QString BeautyDialog::getCmd(QString file) {
	QString retval = "robcpp -ylcnc ";

	if (b1_->isChecked()) {
		Global::instance()->beauty_bcl = true;
		retval += "-bcl ";
	}
	else {
		Global::instance()->beauty_bcl = false;
		retval += "-bnl ";
	}

	if (b3_->isChecked()) {
		Global::instance()->beauty_tbcl = true;
		retval += "-tbcl ";
	}
	else {
		Global::instance()->beauty_tbcl = false;
		retval += "-tbnl ";
	}

	if (b5_->isChecked()) {
		Global::instance()->beauty_tab = true;
		retval += "-t ";
	}
	else {
		Global::instance()->beauty_tab = false;
		retval += "-s ";
	}

	retval += file;

	return retval;
}
